from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists, config
import tsugu_api_async
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, MultiVar


async def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["查角色"],
        Args["word#角色名，乐队，昵称等查询参数", MultiVar(str)],
        meta=CommandMeta(
            compact=config.compact, description="查询角色信息",
            usage='根据关键词或角色ID查询角色信息',
            example='''查角色 10 :返回10号角色的信息。
查角色 吉他 :返回所有角色模糊搜索标签中包含吉他的角色列表。'''
        )
    ).parse(message)

    if res.matched:
        return await tsugu_api_async.search_character(user.default_server, " ".join(res.word))

    return res



from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists, config
import tsugu_api_async
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
from tsugu_api_core._typing import _ServerName


async def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["ycxall", "ycx all"],
        Args['eventId;?#活动ID，省略时查询当前活动。', int]
            ['serverName#省略服务器名时，默认从你当前的主服务器查询。活动ID不存在时，也可以作为第二个参数。', _ServerName.__args__, None],
        meta=CommandMeta(
            compact=config.compact, description="查询指定档位的预测线",
            usage='根据关键词或角色ID查询角色信息',
            example='''ycx 1000 :返回默认服务器当前活动1000档位的档线与预测线。
ycx 1000 177 jp:返回日服177号活动1000档位的档线与预测线。'''
        )
    ).parse(message)

    if res.matched:
        server = server_name_2_server_id(res.serverName) if res.serverName else user.server_mode
        return await tsugu_api_async.ycx_all(server, res.eventId)

    return res



from ...utils import text_response, User, config
import tsugu_api_async
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager


async def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["ycm", "车来", "有车吗"],
        meta=CommandMeta(
            compact=config.compact, description="获取车牌",
        )
    ).parse(message)

    if res.matched:
        return car_search()
    return res


async def car_search():
    try:
        data = await tsugu_api_async.query_room_number()
    except Exception as e:
        return text_response('获取房间信息失败，请稍后再试')
    if not data:
        return text_response('myc')

    new_data = []
    for i in data:
        if isinstance(i['number'], str):
            i['number'] = int(i['number'])
        i['source'] = i['source_info']['name']
        i['userId'] = i['user_info']['user_id']
        i['time'] = i['time']
        i['avanter'] = i['user_info']['avatar']
        i['userName'] = i['user_info']['username']
        i['rawMessage'] = i['raw_message']
        new_data.append(i)
    # 过滤掉 number 相同的
    new_data = list({v['number']: v for v in new_data}.values())

    return await tsugu_api_async.room_list(new_data)




from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists, config
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager
from tsugu_api_core._typing import _ServerName


def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["玩家状态"],
        Args["serverName", _ServerName.__args__, None]["serverIndex", int, None],
        meta=CommandMeta(
            compact=config.compact, description="查询自己的玩家状态",
            usage='根据关键词或活动ID查询活动信息',
            example='''玩家状态 :返回玩家状态(优先当前服务器下第一条记录)
玩家状态 1 :返回绑定的第一条记录的状态
玩家状态 jp :返回绑定的cn服务器的记录的状态'''
        )
    ).parse(message)

    if res.matched:
        if res.serverName:
            return _case_server(user, res.serverName)
        elif res.serverIndex:
            return _case_index(user, res.serverIndex)
        else:
            return _case_default(user)
    return res



def _utils_search_player_by_game_id(game_id, additional_text=""):
    player_id = str(game_id.get("game_id"))
    server = int(game_id.get("server"))
    response = tsugu_api.search_player(int(player_id), server)
    return response + text_response(additional_text)


def _case_default(user: User):
    # 优先当前服务器
    for game_id in user.game_ids:
        if game_id.get("server") == user.server_mode:
            text = f'已查找默认服务器 {server_id_2_server_name(user.server_mode)} 的记录。'
            return _utils_search_player_by_game_id(game_id, text)
    # 兜底逻辑：使用第一个记录
    if user.game_ids:
        game_id = user.game_ids[0]
        text = f'已查找第一个记录。'
        return _utils_search_player_by_game_id(game_id, text)
    return text_response('未绑定任何记录，可以使用 绑定玩家 进行绑定')


def _case_server(user: User, server_name: str):
    server_id = server_name_2_server_id(server_name)
    # 服务器不存在
    if not server_exists(server_id):
        return text_response(f'服务器 {server_name} 不存在。')
    # 查找记录
    for game_id in user.game_ids:
        if game_id.get("server") == server_id:
            # 找到记录
            return _utils_search_player_by_game_id(game_id)
    # 未找到记录
    return text_response(f'未在记录中找到服务器 {server_name} 的记录。')


def _case_index(user: User, index: int):
    if index > len(user.game_ids) or index < 1:
        return text_response(f'未找到记录 {index}。')
    return _utils_search_player_by_game_id(user.game_ids[index - 1])





from ...utils import text_response, User, server_id_2_server_name, server_names_2_server_ids, server_exists, config
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager, MultiVar
from tsugu_api_core._typing import _ServerName


def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["设置默认服务器", "默认服务器"],
        Args["serverList#使用空格分隔服务器列表。", MultiVar(_ServerName)],
        meta=CommandMeta(
            compact=config.compact, description="设定信息显示中的默认服务器排序",
            example="""设置默认服务器 cn jp : 将国服设置为第一服务器，日服设置为第二服务器。"""

        )
    ).parse(message)

    if res.matched:
        r = tsugu_api.change_user_data(platform, user.user_id, {'default_server': server_names_2_server_ids(res.serverList)})
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response('默认服务器已设置为 ' + ' '.join(res.serverList))
    
    return res



class Config:
    def __init__(self):
        self.compact = True
        self.remote_data_max_retry = 3
        self.bandori_station_token_name = "Tsugu"
        self.bandori_station_token = "ZtV4EX2K9Onb"
        self.disable_gacha_simulate_group_ids = []


config = Config()





from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists, config
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager


def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["查卡面", "查插画"],
        Args["cardId", int],
        meta=CommandMeta(
            compact=config.compact, description="查卡面",
            usage='根据卡片ID查询卡片插画',
            example='查卡面 1399 :返回1399号卡牌的插画'
        )
    ).parse(message)

    if res.matched:
        return tsugu_api.get_card_illustration(res.cardId)

    return res




from ...utils import text_response, User, server_id_2_server_name, server_name_2_server_id, server_exists, config
import tsugu_api
from arclet.alconna import Alconna, Option, Subcommand, Args, CommandMeta, Empty, Namespace, namespace, command_manager


def handler(message: str, user: User, platform: str, channel_id: str):
    res = Alconna(
        ["开启车牌转发", "开启个人车牌转发"],
        meta=CommandMeta(
            compact=config.compact, description="开启车牌转发",)
    ).parse(message)

    if res.matched:
        update = {'car': True, }
        r = tsugu_api.change_user_data(platform, user.user_id, update)
        if r.get('status') != 'success':
            return text_response(r.get('data'))
        return text_response('开启车牌转发成功！')
    return res

